@@ -737,7 +737,8 @@ void _gpgrt_process_release (gpgrt_process_t process);
 
 
 /* Close all file resources (descriptors), except KEEP_FDS.  */
-void _gpgrt_close_all_fds (int from, const int *keep_fds);
+void _gpgrt_close_all_fds (int from, const int *keep_fds,
+                           int fallback_max_fds);
 
 
 /*
@@ -839,8 +840,10 @@ char *_gpgrt_getpwdir (const char *name);
 char *_gpgrt_getusername (void);
 
 /* Expand and concat file name parts.  */
-char *_gpgrt_vfnameconcat (int want_abs, const char *first_part,
+char *_gpgrt_vfnameconcat (unsigned int flags, const char *first_part,
                            va_list arg_ptr);
+char *_gpgrt_fconcat (unsigned int flags, const char *first_part,
+                      ... ) GPGRT_ATTR_SENTINEL(0);
 char *_gpgrt_fnameconcat (const char *first_part,
                           ... ) GPGRT_ATTR_SENTINEL(0);
 char *_gpgrt_absfnameconcat (const char *first_part,
@@ -862,6 +865,15 @@ char *_gpgrt_w32_reg_get_string (const char *key);
 
 wchar_t *_gpgrt_fname_to_wchar (const char *fname);
 
+enum gpgrt_windows_feature
+  {
+    GPGRT_WINDOWS_PROC_ATTRIBUTE,
+    GPGRT_WINDOWS_UNDER_WINE
+  };
+int _gpgrt_windows_feature (int);
+
+const char *_gpgrt_w32_get_sysconfdir (void);
+const char *_gpgrt_w32_get_profile (void);
 
 #endif /*HAVE_W32_SYSTEM*/
 
