@@ -7,12 +7,12 @@
    modify it under the terms of the GNU Lesser General Public License
    as published by the Free Software Foundation; either version 2.1 of
    the License, or (at your option) any later version.
- 
+
    libgpg-error is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
- 
+
    You should have received a copy of the GNU Lesser General Public
    License along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
@@ -47,13 +47,17 @@ struct tls_space_s
   int gt_use_utf8;
 };
 
+/* Force UTF8 for new threads.  */
+void _gpgrt_w32_utf8_for_new_threads (void);
+
 /* Return the TLS.  */
 struct tls_space_s *get_tls (void);
 
 
-/* Explicit constructor for w32-gettext.c  */
+/* Explicit constructors for w32-gettext.c and w32-utils.c */
 #ifndef DLL_EXPORT
 void _gpg_w32__init_gettext_module (void);
+void _gpgrt_w32__init_utils (void);
 #endif
 
 #endif /*HAVE_W32_SYSTEM*/
