@@ -228,9 +228,37 @@ MARK_VISIBLE (gpgrt_cmp_version)
 
 MARK_VISIBLE (gpgrt_fnameconcat)
 MARK_VISIBLE (gpgrt_absfnameconcat)
+MARK_VISIBLE (gpgrt_fconcat)
+
+MARK_VISIBLE (gpgrt_strlist_free)
+MARK_VISIBLE (gpgrt_strlist_add)
+MARK_VISIBLE (gpgrt_strlist_tokenize)
+MARK_VISIBLE (gpgrt_strlist_copy)
+MARK_VISIBLE (gpgrt_strlist_rev)
+MARK_VISIBLE (gpgrt_strlist_prev)
+MARK_VISIBLE (gpgrt_strlist_last)
+MARK_VISIBLE (gpgrt_strlist_pop)
+MARK_VISIBLE (gpgrt_strlist_find)
+
+MARK_VISIBLE (gpgrt_nvc_new)
+MARK_VISIBLE (gpgrt_nvc_release)
+MARK_VISIBLE (gpgrt_nvc_get_flag)
+MARK_VISIBLE (gpgrt_nvc_add)
+MARK_VISIBLE (gpgrt_nvc_set)
+MARK_VISIBLE (gpgrt_nve_set)
+MARK_VISIBLE (gpgrt_nvc_delete)
+MARK_VISIBLE (gpgrt_nvc_lookup)
+MARK_VISIBLE (gpgrt_nvc_parse)
+MARK_VISIBLE (gpgrt_nvc_write)
+MARK_VISIBLE (gpgrt_nve_next)
+MARK_VISIBLE (gpgrt_nve_name)
+MARK_VISIBLE (gpgrt_nve_value)
+MARK_VISIBLE (gpgrt_nvc_get_string)
+MARK_VISIBLE (gpgrt_nvc_get_bool)
 
 MARK_VISIBLE (gpgrt_spawn_actions_new)
 MARK_VISIBLE (gpgrt_spawn_actions_release)
+MARK_VISIBLE (gpgrt_spawn_actions_set_env_rev)
 #ifdef HAVE_W32_SYSTEM
 MARK_VISIBLE (gpgrt_spawn_actions_set_envvars)
 MARK_VISIBLE (gpgrt_spawn_actions_set_redirect)
@@ -423,6 +451,7 @@ MARK_VISIBLE (gpgrt_spawn_actions_set_atfork)
 
 #define gpgrt_spawn_actions_new                 _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_spawn_actions_release             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_spawn_actions_set_env_rev         _gpgrt_USE_UNDERSCORED_FUNCTION
 #ifdef HAVE_W32_SYSTEM
 #define gpgrt_spawn_actions_set_envvars         _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_spawn_actions_set_redirect        _gpgrt_USE_UNDERSCORED_FUNCTION
@@ -446,6 +475,33 @@ MARK_VISIBLE (gpgrt_spawn_actions_set_atfork)
 #define gpgrt_cmp_version           _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_fnameconcat           _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_absfnameconcat        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_fconcat               _gpgrt_USE_UNDERSCORED_FUNCTION
+
+#define gpgrt_strlist_free          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_add           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_tokenize      _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_copy          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_rev           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_prev          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_last          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_pop           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_strlist_find          _gpgrt_USE_UNDERSCORED_FUNCTION
+
+#define gpgrt_nvc_new               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_release           _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_flag          _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_add               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_set               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_set               _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_delete            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_lookup            _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_parse             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_write             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_next              _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_name              _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nve_value             _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_string        _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_nvc_get_bool          _gpgrt_USE_UNDERSCORED_FUNCTION
 
 /* Windows specific functions.  */
 #define gpgrt_free_wchar            _gpgrt_USE_UNDERSCORED_FUNCTION
@@ -453,6 +509,7 @@ MARK_VISIBLE (gpgrt_spawn_actions_set_atfork)
 #define gpgrt_wchar_to_utf8         _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_fname_to_wchar        _gpgrt_USE_UNDERSCORED_FUNCTION
 #define gpgrt_w32_reg_query_string  _gpgrt_USE_UNDERSCORED_FUNCTION
+#define gpgrt_w32_reg_get_string    _gpgrt_USE_UNDERSCORED_FUNCTION
 
 
 #endif /*!_GPGRT_INCL_BY_VISIBILITY_C*/
