@@ -61,6 +61,8 @@ static struct
   char name[28];
 } override_locale;
 
+/* This is the dynloaded GetThreadUILanguage() or NULL.  */
+static LANGID (WINAPI *get_thread_ui_language)(void);
 
 
 
@@ -648,8 +650,10 @@ my_nl_locale_name (const char *categoryname)
       if (retval != NULL && retval[0] != '\0')
         return retval;
 
-      /* Use native Win32 API locale ID.  */
-      lcid = GetThreadLocale ();
+      /* Use native Win32 API language ID or use GetThreadLocale on XP  */
+      lcid = get_thread_ui_language? get_thread_ui_language ()
+                                   : GetThreadLocale ();
+
       /* Strip off the sorting rules, keep only the language part.  */
       langid = LANGIDFROMLCID (lcid);
     }
@@ -1154,6 +1158,7 @@ static CRITICAL_SECTION domainlist_access_cs;
 static char *current_domainname;
 
 
+
 
 /* Constructor for this module.  This can only be used if we are a
    DLL.  If used as a static lib we can't control the process set; for
@@ -1166,10 +1171,16 @@ static void
 module_init (void)
 {
   static int init_done;
+  HMODULE hkernel32;
 
   if (!init_done)
     {
       InitializeCriticalSection (&domainlist_access_cs);
+
+      hkernel32 = GetModuleHandle ("kernel32.dll");
+      if (hkernel32)
+        get_thread_ui_language = (void*)GetProcAddress (hkernel32,
+                                                        "GetThreadUILanguage");
       init_done = 1;
     }
 }
@@ -1947,17 +1958,23 @@ _gpg_w32_gettext_localename (void)
 }
 
 
-/* With a VALUE of 1 switch the gettext functions into utf8 mode.
-   That is the strings are returned without translation to the native
-   charset.  A VALUE of 0 switches back to translated strings.  A VALUE
-   of -1 returns the current value. */
+/* With a VALUE of 1 switch the gettext functions into utf8 mode; with
+ * 2 or 3 all new threads will initially be using UTF8.  That is the
+ * strings are returned without translation to the native charset.  A
+ * VALUE of 0 switches back to translated strings.  A VALUE of -1
+ * returns the current value. */
 int
 _gpg_w32_gettext_use_utf8 (int value)
 {
   struct tls_space_s *tls = get_tls ();
   int last = tls->gt_use_utf8;
   if (value != -1)
-    tls->gt_use_utf8 = value;
+    {
+      tls->gt_use_utf8 = !!value;
+
+      if ((value & 2))
+        _gpgrt_w32_utf8_for_new_threads ();
+    }
   return last;
 }
 
